@@ -190,8 +190,8 @@ class ListWorktimeByUserMain:
 
         return working_time_by_user.get("description")
 
+    @staticmethod
     def _get_labor_worktime(
-        self,
         labor: Dict[str, Any],
         member: Optional[ProjectMember],
         project_title: str,
@@ -208,9 +208,9 @@ class ListWorktimeByUserMain:
             user_id=member["user_id"] if member is not None else labor["account_id"],
             username=member["username"] if member is not None else labor["account_id"],
             biography=member["biography"] if member is not None else None,
-            worktime_plan_hour=self.get_worktime_hour(labor["values"]["working_time_by_user"], "plans"),
-            worktime_result_hour=self.get_worktime_hour(labor["values"]["working_time_by_user"], "results"),
-            working_description=self._get_working_description(labor["values"]["working_time_by_user"]),
+            worktime_plan_hour=labor["plan_worktime"] if labor["plan_worktime"] is not None else 0,
+            worktime_result_hour=labor["actual_worktime"] if labor["actual_worktime"] is not None else 0,
+            working_description=labor["working_description"],
             worktime_monitored_hour=worktime_monitored_hour,
         )
         return new_labor
@@ -234,13 +234,10 @@ class ListWorktimeByUserMain:
         labor_availability_dict = {}
         for user in user_list:
             # 予定稼働時間を取得するには、特殊な組織IDを渡す
-            labor_list, _ = self.service.api.get_labor_control(
-                {
-                    "organization_id": "___plannedWorktime___",
-                    "from": start_date,
-                    "to": end_date,
-                    "account_id": user.account_id,
-                }
+            labor_list = self.service.wrapper.get_labor_control_availability(
+                from_date=start_date,
+                to_date=end_date,
+                account_id=user.account_id,
             )
             new_labor_list = []
             for labor in labor_list:
@@ -249,7 +246,7 @@ class ListWorktimeByUserMain:
                     account_id=labor["account_id"],
                     user_id=user.user_id,
                     username=user.username,
-                    availability_hour=self.get_worktime_hour(labor["values"]["working_time_by_user"], "plans"),
+                    availability_hour=labor["availability"] if labor["availability"] is not None else 0,
                 )
                 new_labor_list.append(new_labor)
             labor_availability_dict[user.user_id] = new_labor_list
@@ -258,6 +255,7 @@ class ListWorktimeByUserMain:
     def get_labor_list_from_project_id(
         self,
         project_id: str,
+        account_id_list: Optional[List[str]],
         start_date: Optional[str],
         end_date: Optional[str],
         add_monitored_worktime: bool = False,
@@ -265,16 +263,30 @@ class ListWorktimeByUserMain:
         organization, _ = self.service.api.get_organization_of_project(project_id)
         organization_name = organization["organization_name"]
 
-        labor_list, _ = self.service.api.get_labor_control(
-            {
-                "project_id": project_id,
-                "organization_id": organization["organization_id"],
-                "from": start_date,
-                "to": end_date,
-            }
-        )
-        project_title = self.service.api.get_project(project_id)[0]["title"]
+        if account_id_list is None:
+            logger.debug(f"project_id={project_id}の、すべての労務管理情報を取得しています。")
+            labor_list = self.service.wrapper.get_labor_control_worktime(
+                project_id=project_id,
+                organization_id=organization["organization_id"],
+                from_date=start_date,
+                to_date=end_date,
+            )
+        else:
+            labor_list = []
+            for account_id in account_id_list:
+                logger.debug(f"project_id={project_id}の、ユーザ{len(account_id_list)}件分の労務管理情報を取得しています。")
+                tmp_labor_list = self.service.wrapper.get_labor_control_worktime(
+                    project_id=project_id, from_date=start_date, to_date=end_date, account_id=account_id
+                )
+                labor_list.extend(tmp_labor_list)
 
+        project_title = self.service.api.get_project(project_id)[0]["title"]
+        labor_list = [
+            e
+            for e in labor_list
+            if (e["actual_worktime"] is not None and e["actual_worktime"] > 0)
+            or (e["plan_worktime"] is not None and e["plan_worktime"] > 0)
+        ]
         logger.info(f"'{project_title}'プロジェクト('{project_id}')の労務管理情報の件数: {len(labor_list)}")
 
         new_labor_list = []
@@ -309,18 +321,38 @@ class ListWorktimeByUserMain:
     def get_labor_list_from_organization_name(
         self,
         organization_name: str,
+        account_id_list: Optional[List[str]],
         start_date: Optional[str],
         end_date: Optional[str],
         add_monitored_worktime: bool = False,
     ) -> List[LaborWorktime]:
         organization, _ = self.service.api.get_organization(organization_name)
         organization_id = organization["organization_id"]
+
+        if account_id_list is None:
+            logger.debug(f"organization_name={organization_name}の、すべての労務管理情報を取得しています。")
+            labor_list = self.service.wrapper.get_labor_control_worktime(
+                organization_id=organization_id, from_date=start_date, to_date=end_date
+            )
+        else:
+            labor_list = []
+            logger.debug(f"organization_name={organization_name}の、ユーザ{len(account_id_list)}件分の労務管理情報を取得しています。")
+            for account_id in account_id_list:
+                tmp_labor_list = self.service.wrapper.get_labor_control_worktime(
+                    organization_id=organization_id, from_date=start_date, to_date=end_date, account_id=account_id
+                )
+                labor_list.extend(tmp_labor_list)
+
+        labor_list = [
+            e
+            for e in labor_list
+            if (e["actual_worktime"] is not None and e["actual_worktime"] > 0)
+            or (e["plan_worktime"] is not None and e["plan_worktime"] > 0)
+        ]
+
+        logger.info(f"'{organization_name}'組織の労務管理情報の件数: {len(labor_list)}")
         project_list = self.service.wrapper.get_all_projects_of_organization(organization_name)
 
-        labor_list, _ = self.service.api.get_labor_control(
-            {"organization_id": organization_id, "from": start_date, "to": end_date}
-        )
-        logger.info(f"'{organization_name}'組織の労務管理情報の件数: {len(labor_list)}")
         new_labor_list = []
         for labor in labor_list:
             try:
@@ -403,7 +435,6 @@ class ListWorktimeByUserMain:
 
         username_list = [e[0] for e in sum_worktime_df.columns if is_plan_column(e)]
 
-        sum_worktime_df.to_csv("foo.csv", encoding="utf_8_sig", index=False)
         for username in username_list:
             # SettingWithCopyWarning を避けるため、暫定的に値をコピーする
             sum_worktime_df[(username, "作業予定_記号")] = sum_worktime_df[(username, "作業予定")].map(create_mark)
@@ -637,6 +668,80 @@ class ListWorktimeByUserMain:
 
         return availability_list
 
+    def get_account_id_list_from_project_id(self, user_id_list: List[str], project_id_list: List[str]) -> List[str]:
+        """
+        project_idのリストから、対象ユーザのaccount_id を取得する。
+
+        Args:
+            user_id_list:
+            organization_name_list:
+
+        Returns:
+            account_idのリスト
+        """
+        account_id_list = []
+        not_exists_user_id_list = []
+        for user_id in user_id_list:
+            member_exists = False
+            for project_id in project_id_list:
+                member = self.facade.get_project_member_from_user_id(project_id, user_id)
+                if member is not None:
+                    account_id_list.append(member["account_id"])
+                    member_exists = True
+                    break
+            if not member_exists:
+                not_exists_user_id_list.append(user_id)
+
+        if len(not_exists_user_id_list) == 0:
+            return account_id_list
+        else:
+            raise ValueError(f"以下のユーザは、指定されたプロジェクトのプロジェクトメンバではありませんでした。\n{not_exists_user_id_list}")
+
+    def get_account_id_list_from_organization_name(
+        self, user_id_list: List[str], organization_name_list: List[str]
+    ) -> List[str]:
+        """
+        組織名のリストから、対象ユーザのaccount_id を取得する。
+
+        Args:
+            user_id_list:
+            organization_name_list:
+
+        Returns:
+            account_idのリスト
+        """
+
+        def _get_account_id(fuser_id: str) -> Optional[str]:
+            # 脱退した可能性のあるユーザの組織メンバ情報を取得する
+            for organization_name in organization_name_list:
+                member = self.service.wrapper.get_organization_member_or_none(organization_name, fuser_id)
+                if member is not None:
+                    return member["account_id"]
+            return None
+
+        # 組織メンバの一覧をする（ただし脱退したメンバは取得できない）
+        all_organization_member_list = []
+        for organization_name in organization_name_list:
+            all_organization_member_list.extend(self.service.wrapper.get_all_organization_members(organization_name))
+
+        user_id_dict = {e["user_id"]: e["account_id"] for e in all_organization_member_list}
+        account_id_list = []
+        not_exists_user_id_list = []
+        for user_id in user_id_list:
+            if user_id in user_id_dict:
+                account_id_list.append(user_id_dict[user_id])
+            else:
+                account_id = _get_account_id(user_id)
+                if account_id is not None:
+                    account_id_list.append(account_id)
+                else:
+                    not_exists_user_id_list.append(user_id)
+
+        if len(not_exists_user_id_list) == 0:
+            return account_id_list
+        else:
+            raise ValueError(f"以下のユーザは、指定された組織の組織メンバではありませんでした。\n{not_exists_user_id_list}")
+
     def get_labor_list(
         self,
         organization_name_list: Optional[List[str]],
@@ -648,13 +753,20 @@ class ListWorktimeByUserMain:
     ) -> List[LaborWorktime]:
 
         labor_list: List[LaborWorktime] = []
+        account_id_list: Optional[List[str]] = None
 
         logger.info(f"労務管理情報を取得します。")
         if project_id_list is not None:
+            if user_id_list is not None:
+                account_id_list = self.get_account_id_list_from_project_id(
+                    user_id_list, project_id_list=project_id_list
+                )
+
             for project_id in project_id_list:
                 labor_list.extend(
                     self.get_labor_list_from_project_id(
                         project_id,
+                        account_id_list=account_id_list,
                         start_date=start_date,
                         end_date=end_date,
                         add_monitored_worktime=add_monitored_worktime,
@@ -662,10 +774,15 @@ class ListWorktimeByUserMain:
                 )
 
         elif organization_name_list is not None:
+            if user_id_list is not None:
+                account_id_list = self.get_account_id_list_from_organization_name(
+                    user_id_list, organization_name_list=organization_name_list
+                )
             for organization_name in organization_name_list:
                 labor_list.extend(
                     self.get_labor_list_from_organization_name(
                         organization_name,
+                        account_id_list=account_id_list,
                         start_date=start_date,
                         end_date=end_date,
                         add_monitored_worktime=add_monitored_worktime,
@@ -855,17 +972,6 @@ class ListWorktimeByUserMain:
         labor_availability_list_dict: Optional[Dict[str, List[LaborAvailability]]] = None,
         add_monitored_worktime: bool = False,
     ):
-        # 行方向に日付、列方向にユーザを表示したDataFrame
-        sum_worktime_df = self.create_sum_worktime_df(
-            labor_list=labor_list,
-            user_list=user_list,
-            start_date=start_date,
-            end_date=end_date,
-            labor_availability_list_dict=labor_availability_list_dict,
-        )
-        self.write_sum_worktime_list(sum_worktime_df, output_dir)
-        self.write_sum_plan_worktime_list(sum_worktime_df, output_dir)
-
         if len(labor_list) > 0:
             worktime_df = pandas.DataFrame([e.to_dict() for e in labor_list])
             self.write_worktime_list(worktime_df, output_dir, add_monitored_worktime)
@@ -889,6 +995,17 @@ class ListWorktimeByUserMain:
         )
         self.write_worktime_per_user(worktime_df_per_user, output_dir, add_availability=add_availability)
 
+        # 行方向に日付、列方向にユーザを表示したDataFrame
+        sum_worktime_df = self.create_sum_worktime_df(
+            labor_list=labor_list,
+            user_list=user_list,
+            start_date=start_date,
+            end_date=end_date,
+            labor_availability_list_dict=labor_availability_list_dict,
+        )
+        self.write_sum_worktime_list(sum_worktime_df, output_dir)
+        self.write_sum_plan_worktime_list(sum_worktime_df, output_dir)
+
     def main(
         self,
         organization_name_list: Optional[List[str]],
@@ -919,11 +1036,11 @@ class ListWorktimeByUserMain:
                 return
 
         if start_date is None or end_date is None:
-            sorted_labor_list = sorted(labor_list, key=lambda e: e.date)
+            sorted_date_list = sorted({e.date for e in labor_list if e.worktime_result_hour > 0})
             if start_date is None:
-                start_date = sorted_labor_list[0].date
+                start_date = sorted_date_list[0]
             if end_date is None:
-                end_date = sorted_labor_list[-1].date
+                end_date = sorted_date_list[-1]
 
         logger.info(f"集計期間: start_date={start_date}, end_date={end_date}")
         user_list = self.get_user_list(
